@@ -3,9 +3,9 @@ from asyncio import sleep
 from typing import List
 from loguru import logger
 from pydantic import BaseModel
-from ayaka import AyakaApp, MessageSegment, Message
+from ayaka import AyakaBox, MessageSegment, Message, AyakaConfig
 
-app = AyakaApp("坏词撤回")
+app = AyakaBox("坏词撤回")
 app.help = '''自动撤回包含屏蔽词的消息'''
 
 
@@ -15,11 +15,19 @@ class WordPackage(BaseModel):
     groups: List[int] = []
 
 
-class Config(app.BaseConfig):
+default_word_packages = [
+    WordPackage(name="示例词包1", words=["芝士雪豹", "雪豹闭嘴"], groups=["12311211"]),
+    WordPackage(name="示例词包2", words=["wtf", "holy shit"], groups=[
+                "12311211", "389019292"])
+]
+
+
+class Config(AyakaConfig):
+    __config_name__ = app.name
     delay: int = 0
     powerful: int = 0
     tip: str = "请谨言慎行"
-    word_packages: List[WordPackage] = [WordPackage(name="示例词包", words=["芝士雪豹", "雪豹闭嘴"])]
+    word_packages: List[WordPackage] = default_word_packages
 
 
 config = Config()
@@ -43,8 +51,7 @@ def check(msg: str, group_id: int):
             return True
 
 
-@app.on.idle()
-@app.on.text()
+@app.on_text(always=True)
 async def bad_words():
     msg = app.event.get_plaintext()
     mid = app.event.message_id
